@@ -277,7 +277,8 @@ def dbt_dag_factory_new(
     run_flags=None,  # e.g. --model tag:base
     project=None,  # BigQuery alias
     dataset=None,  # BigQuery alias
-    dagrun_timeout_factor=0.8,
+    dagrun_timeout_factor=None,  # doesn't apply to full refresh
+    task_timeout_factor=0.8,  # doesn't apply to full refresh
 ):
     run_flags = run_flags or ""  # use empty string instead of None
 
@@ -310,12 +311,25 @@ def dbt_dag_factory_new(
         assert isinstance(dagrun_timeout_factor, (int, float)) and (
             0 < dagrun_timeout_factor <= 1
         ), _msg
-        dag_kwargs["dagrun_timeout"] = dagrun_timeout_factor * schedule_interval
-        dag_kwargs["default_args"]["execution_timeout"] = dag_kwargs[
-            "default_args"
-        ].get("execution_timeout", dag_kwargs["dagrun_timeout"])
+        dagrun_timeout = dagrun_timeout_factor * schedule_interval
+    else:
+        dagrun_timeout = None
 
-    dag_1 = DAG(dag_base_name, schedule_interval=schedule_interval, **dag_kwargs)
+    if task_timeout_factor:
+        _msg = "task_timeout_factor must be a number between 0 and 1!"
+        assert isinstance(task_timeout_factor, (int, float)) and (
+            0 < task_timeout_factor <= 1
+        ), _msg
+        execution_timeout = task_timeout_factor * schedule_interval
+    else:
+        execution_timeout = None
+
+    dag_1 = DAG(
+        dag_base_name,
+        schedule_interval=schedule_interval,
+        dagrun_timeout=dagrun_timeout,
+        **dag_kwargs,
+    )
     dag_2 = DAG(dag_base_name + "_full_refresh", schedule_interval=None, **dag_kwargs)
 
     sensor_sql = """
@@ -378,6 +392,7 @@ def dbt_dag_factory_new(
         task_id="dbt_run",
         dbt_commands=["seed", f"run {run_flags}"],
         dag=dag_1,
+        execution_timeout=execution_timeout,
         **dbt_kwargs,
     )
     run_2 = EWAHdbtOperator(
@@ -388,7 +403,11 @@ def dbt_dag_factory_new(
     )
 
     test_1 = EWAHdbtOperator(
-        task_id="dbt_test", dbt_commands="test", dag=dag_1, **dbt_kwargs
+        task_id="dbt_test",
+        dbt_commands="test",
+        dag=dag_1,
+        execution_timeout=execution_timeout,
+        **dbt_kwargs,
     )
     test_2 = EWAHdbtOperator(
         task_id="dbt_test", dbt_commands="test", dag=dag_2, **dbt_kwargs
@@ -421,7 +440,8 @@ def dbt_snapshot_dag(
     schedule_interval=timedelta(hours=1),
     start_date=None,
     default_args=None,
-    dagrun_timeout_factor=0.8,
+    dagrun_timeout_factor=None,
+    task_timeout_factor=0.8,
 ):
     # only PostgreSQL & Snowflake implemented as of now!
     assert dwh_engine in (EC.DWH_ENGINE_POSTGRES, EC.DWH_ENGINE_SNOWFLAKE)
@@ -432,13 +452,18 @@ def dbt_snapshot_dag(
             0 < dagrun_timeout_factor <= 1
         ), _msg
         dagrun_timeout = dagrun_timeout_factor * schedule_interval
-        default_args = default_args or {}
-        default_args["execution_timeout"] = default_args.get(
-            "execution_timeout", dagrun_timeout
-        )
     else:  # In case of 0 set to None
         dagrun_timeout = None
 
+    if task_timeout_factor:
+        _msg = "dagrun_timeout_factor must be a number between 0 and 1!"
+        assert isinstance(task_timeout_factor, (int, float)) and (
+            0 < task_timeout_factor <= 1
+        ), _msg
+        execution_timeout = task_timeout_factor * schedule_interval
+    else:
+        execution_timeout = None
+
     dag = DAG(
         dag_name,
         schedule_interval=schedule_interval,
@@ -463,6 +488,7 @@ def dbt_snapshot_dag(
         threads=threads,
         schema_name=schema_name,
         keepalives_idle=keepalives_idle,
+        execution_timeout=execution_timeout,
     )
 
     return dag
